@@ -9,8 +9,10 @@ from .method import (
     Manual,
     PortalSSOToken,
     DosejongSession,
+    MoodlerSession,
+    ClassicSession,
 )
 
 
 __AUTHOR__ = "IML"
-__VERSION__ = "0.1.2"
\ No newline at end of file
+__VERSION__ = "0.3.3"
\ No newline at end of file
